"""
Django settings for investment_game project.

See https://docs.djangoproject.com/en/2.2/howto/deployment/checklist/

For more information on this file, see
https://docs.djangoproject.com/en/2.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.2/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

ALLOWED_HOSTS = []

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

# SECURITY WARNING: keep the secret key used in production secret!
if BASE_DIR.startswith('/usr/local/'):
    with open('/usr/local/etc/investment-game/secret.key') as fh:
        SECRET_KEY = fh.readline().strip()
elif BASE_DIR.startswith('/usr/'):
    with open('/etc/investment-game/secret.key') as fh:
        SECRET_KEY = fh.readline().strip()
else:
    # SECURITY WARNING: don't run with debug turned on in production!
    DEBUG = True
    SECRET_KEY = 'm+qe=y&76!r@fmx$nxf)+hrc@hbjr)$3@a8sjtt9=urgzsf937'

if not DEBUG:
    LOGGING = {
        'version': 1,
        'disable_existing_loggers': False,
        'handlers': {
            'syslog': {
                'class': 'logging.handlers.SysLogHandler',
                'address': '/dev/log',
                'level': 'DEBUG',
            },
        },
        'loggers': {
            # Redefine these because they're defined by the default
            # Django logging config:
            'django': {
                'handlers': ['syslog'],
                'level': 'DEBUG',
                'propagate': True,
            },
            'django.server': {
                'handlers': ['syslog'],
                'level': 'DEBUG',
                'propagate': True,
            },
        },
        'root': {
            # Everything else goes here:
            'handlers': ['syslog'],
            'level': 'DEBUG',
        },
    }

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django_filters',
    'rest_framework',
    'investment_game.game',
    'investment_game.stocks',
    'investment_game.uvt',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.RemoteUserMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'investment_game.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'investment_game.wsgi.application'

# Database
# https://docs.djangoproject.com/en/2.2/ref/settings/#databases

DATABASES = {
    'default': {
        #       'ENGINE': 'django.db.backends.sqlite3',
        #       'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
        'ENGINE': 'django.db.backends.postgresql',
        'NAME': 'investment-game',
        'USER': 'investment-game',
        'ATOMIC_REQUESTS': True,
        # 'OPTIONS': {
        #     'isolation_level': psycopg2.extensions.ISOLATION_LEVEL_SERIALIZABLE,
        # },
    }
}

# Our custom user model
AUTH_USER_MODEL = 'uvt.User'

AUTHENTICATION_BACKENDS = ['investment_game.auth.backends.RemoteUserBackend']

UVT_USER_BACKEND = {
    'ldap_server_uri': 'ldap://ldap.uvt.nl',
    'search_base': 'o=Universiteit van Tilburg,c=NL',
    'attributes': {
        'mail': 'email',
        'givenName': 'first_name',
        'sn': 'last_name',
        'displayName': 'full_name',
        'employeeNumber': 'anr',
        'emplId': 'student_number',
    },
}

# Password validation
# https://docs.djangoproject.com/en/2.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator'},
    {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator'},
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator'},
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator'},
]

# Internationalization
# https://docs.djangoproject.com/en/2.2/topics/i18n/

LANGUAGE_CODE = 'en'

TIME_ZONE = 'Europe/Amsterdam'

USE_I18N = False

USE_L10N = False

USE_TZ = False

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.2/howto/static-files/

STATIC_URL = '/static/'

# ReST-framework related stuff
REST_FRAMEWORK = {
    'DEFAULT_FILTER_BACKENDS': [
        'django_filters.rest_framework.DjangoFilterBackend',
        'rest_framework.filters.SearchFilter',
        'rest_framework.filters.OrderingFilter',
    ],
    'SEARCH_PARAM': 'q',
}
