"""Models for the stocks module"""

from django.db import models


class Asset(models.Model):
    """Tradeable financial effects"""
    isin = models.CharField(max_length=12, unique=True)
    name = models.TextField()
    ticker = models.TextField()


class AssetPrice(models.Model):
    """Closing price of tradeable financial effects"""
    asset = models.ForeignKey(Asset, on_delete=models.CASCADE)
    currency = models.TextField()
    closing_price = models.DecimalField(max_digits=30, decimal_places=20, null=True)
    closing_time = models.DateTimeField()
    closing_date = models.DateField()
    timezone_name = models.TextField()

    class Meta:
        constraints = [
            models.UniqueConstraint(
                name='unique_asset_date',
                fields=['asset', 'closing_date'],
            ),
        ]


class Index(models.Model):
    """Collection of assets under a certain name (AEX, S&P 500, etcetera)"""
    name = models.TextField()
    assets = models.ManyToManyField(Asset)
