"""Django views for stocks"""

from rest_framework import viewsets
from rest_framework.permissions import BasePermission, SAFE_METHODS
from rest_framework_extensions.mixins import NestedViewSetMixin

from .models import Asset, Index
from .serializers import AssetSerializer, IndexSerializer


class AssetPermission(BasePermission):
    message = "These data are read-only."

    def has_permission(self, request, view):
        return request.method in SAFE_METHODS


class AssetViewSet(NestedViewSetMixin, viewsets.ModelViewSet):
    """API endpoint"""
    queryset = Asset.objects.all()
    serializer_class = AssetSerializer
    filterset_fields = ['name', 'isin', 'ticker']
    search_fields = ['name', '=isin', '=ticker']
    permission_classes = [AssetPermission]


class IndexPermission(BasePermission):
    message = "These data are read-only."

    def has_permission(self, request, view):
        return request.method in SAFE_METHODS


class IndexViewSet(viewsets.ModelViewSet):
    """API endpoint"""
    queryset = Index.objects.all()
    serializer_class = IndexSerializer
    filterset_fields = ['name']
    search_fields = ['name']
    permission_classes = [IndexPermission]
