"""investment_game URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import include, path
from rest_framework_extensions.routers import ExtendedSimpleRouter

from .game.views import (
    GameViewSet,
    JoinView,
    ParticipationViewSet,
    PortfolioViewSet,
    PortfolioRevisionViewSet,
)
from .stocks.views import AssetViewSet, IndexViewSet
from .uvt.views import UserViewSet, SessionView

router = ExtendedSimpleRouter(trailing_slash=False)

users_router = router.register(
    'users',
    UserViewSet,
    basename='user',
)
users_router.register(
    'participations',
    ParticipationViewSet,
    basename='users-participation',
    parents_query_lookups=['user'],
)
users_games_router = users_router.register(
    'games',
    GameViewSet,
    basename='users-game',
    parents_query_lookups=['participation__user'],
)
users_games_router.register(
    'participations',
    ParticipationViewSet,
    basename='users-games-participation',
    parents_query_lookups=['user', 'game'],
)

games_router = router.register(
    'games',
    GameViewSet,
    basename='game',
)
games_router.register(
    'participations',
    ParticipationViewSet,
    basename='games-participation',
    parents_query_lookups=['game'],
)
games_router.register(
    'assets',
    AssetViewSet,
    basename='games-asset',
    parents_query_lookups=['game'],
)

participations_router = router.register(
    'participations',
    ParticipationViewSet,
    basename='participation',
)
participations_router.register(
    'portfolios',
    PortfolioViewSet,
    basename='portfolios-participation',
    parents_query_lookups=['participation'],
)

portfolios_router = router.register(
    'portfolios',
    PortfolioViewSet,
    basename='portfolio',
)
portfolios_router.register(
    'revisions',
    PortfolioRevisionViewSet,
    basename='portfolios-revision',
    parents_query_lookups=['portfolio'],
)

router.register(
    'portfolio-revisions',
    PortfolioRevisionViewSet,
    basename='portfolio-revision',
)

indexes_router = router.register(
    'indexes',
    IndexViewSet,
    basename='index',
)
indexes_router.register(
    'assets',
    AssetViewSet,
    basename='indexes-asset',
    parents_query_lookups=['index'],
)

router.register('assets', AssetViewSet, basename='asset')

urlpatterns = [
    path('', include(router.urls)),
    path('join', JoinView.as_view()),
    path('session', SessionView.as_view()),
    path('admin', admin.site.urls),
]
